# SAP Business One - Python Service Layer wrapper

This package provides a base wrapper for accessing the SAP
service layer in Python.

This is an unstable beta!!!

## Installation

```shell
$ python -m pip install sbo-service-layer
```